From e97275cf12923e97ad4680ecb3c3fd2e2f3e8dba Mon Sep 17 00:00:00 2001
From: mattijs <mattijs>
Date: Thu, 21 Dec 2017 15:05:10 +0000
Subject: [PATCH] ENH: collated support. Fixes createZeroDirectory in #675.

---
 .../createZeroDirectory/createZeroDirectory.C              | 7 +++----
 1 file changed, 3 insertions(+), 4 deletions(-)

diff --git a/applications/utilities/preProcessing/createZeroDirectory/createZeroDirectory.C b/applications/utilities/preProcessing/createZeroDirectory/createZeroDirectory.C
index 0e9b0fbd041..533ced2cffa 100644
--- a/applications/utilities/preProcessing/createZeroDirectory/createZeroDirectory.C
+++ b/applications/utilities/preProcessing/createZeroDirectory/createZeroDirectory.C
@@ -3,7 +3,7 @@
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
     \\  /    A nd           | Copyright (C) 2015 OpenFOAM Foundation
-     \\/     M anipulation  | Copyright (C) 2015 OpenCFD Ltd.
+     \\/     M anipulation  | Copyright (C) 2015-2017 OpenCFD Ltd.
 -------------------------------------------------------------------------------
 License
     This file is part of OpenFOAM.
@@ -133,7 +133,6 @@ void createFieldFiles
     Info<< "    Generating field files" << nl << endl;
 
     // Create files
-    mkDir(runTime.path()/runTime.timeName()/regionName);
     forAll(fieldNames, i)
     {
         const_cast<word&>(IOdictionary::typeName) =
@@ -181,8 +180,8 @@ void createFieldFiles
         field2.remove("initialConditions");
         field2.remove("boundaryConditions");
 
-        // Construct and write field dictionary
-        IOdictionary fieldOut
+        // Construct and write field dictionary. Note use of localIOdictionary
+        localIOdictionary fieldOut
         (
             IOobject
             (
-- 
GitLab